%% dukeletter.cls
%% Revision 2  (April 04 2008)
%% Michael Gratton (mgratton@math.duke.edu)
%% 
%% This is a LaTeX 2e document class for letters.  It is motivated by the
%% previous dukeletter.sty, but does not use any code from it.
%% 
%% This class is built off of the standard letter.cls, and all letter.cls
%% options are also dukeletter.cls options.  The most important are:
%%  [10pt, 11pt, 12pt] -- change the body text size.  Default is 10pt
%%  [letterpaper, a4paper] -- change the paper size.  Default is letterpaper.
%% It also adds a new option
%%  [letterhead]  -- suppress the generation of 'letterhead' and just leave
%%                   space for preprinted letterhead instead.
%% 
%% Data Fields: 
%% By default, data fields are filled with generic parameters
%% suitable for letters from the math department.  You may redefine any of them
%% in the preamble (before \begin{document}) by \telephone{867-5309}, and so
%% on.  Here are the fields.
%% 
%%    sender    (blank)     Your name as it should appear below your signature.
%% 	                      Default is blank, but it will cause spurious
%% 								 compile-time warnings.  Not needed if you fill out
%% 								 the signature field.
%% 	signature ([sender] \\ [email] \\ [telephone])
%% 	                      The actual text below your signature.  Default
%% 								 contains name, email, and phone number
%%    email     (dept@math.duke.edu)
%% 	                      Appears in auto-gen letterhead and under your name.
%% 								 Default is the front office address.
%%    telephone ((919) 660-2800)
%% 	                      Appears in auto-gen letterhead and under you name.
%% 								 Default is front office.
%%    fax       (660-2821)  Appears in auto-gen letterhead.  Default is the 
%% 	                      department fax machine.
%%    date      (\today)    Appears on the right margin.  Default is today.
%% 	address   (Box 90320\\ Durham, NC 27708-0320)
%% 	                      Appears in auto-gen letterhead.  Default is the
%% 								 Mathematics department.  Note 'Duke University' and
%% 								 'Department of Mathematics' don't appear here since
%% 								 they're printed above :)
%%   department (Mathematics)
%%                          Appears in auto-gen letterhead.  Default is for
%% 								 Duke Math, but you could change it.
%%
%% Required packages:
%% Currently, graphics and ifpdf are required for graphics placement.
%% 
%% External Files:
%% If availible, 'dukeshield.pdf' will be used as the logo in the letterhead.
%% If not, a LaTeX picture environment copy will be substituted.

\NeedsTeXFormat{LaTeX2e}[1996/06/01]
\ProvidesClass{dukeletter}[2008/04/03 v0.1]

\newif\if@MakeLetterhead
\@MakeLetterheadtrue
\DeclareOption{letterhead}{\@MakeLetterheadfalse}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{letter}}
\ExecuteOptions{letterpaper, 10pt}
\ProcessOptions\relax
\LoadClass{letter}

\RequirePackage{graphicx}
\RequirePackage{ifpdf}

\newcommand{\department}[1]{\gdef\@department{#1}}
%\newcommand{\phone}[1]{\gdef\@phone{#1}}
\newcommand{\email}[1]{\gdef\fromemail{#1}}
\newcommand{\fax}[1]{\gdef\faxnum{#1}}
\newcommand{\sender}[1]{\gdef\sendername{#1}}
% default values
\email{dept@math.duke.edu}
\department{Mathematics}
\fax{660-2821}
\telephone{(919) 660-2800}
\address{Box 90320\\ Durham, NC 27708-0320}
\sender{ }
\signature{\sendername\relax \\ \texttt{\fromemail\relax} \\ \telephonenum\relax}


\renewcommand*{\opening}[1]{%
  \thispagestyle{firstpage}%
	 \if@MakeLetterhead
		 \vspace*{2\parsep}
	 \else
	    \vspace*{4\parsep}  % insurance against hitting the letterhead
	 \fi
    {\raggedleft\@date \par }%
  \vspace{2\parskip}%
  {\raggedright \toname \\ \toaddress \par }%
  \vspace{2\parskip}%
  #1  \par \nobreak%
}


\setlength\topmargin{\z@}
%\setlength\oddsidemargin{\z@}

% Nasty computation of letterhead size
\newlength\addresslength
\settowidth\addresslength{%
  \usefont{OT1}{cmr}{m}{n}\fontsize{8pt}{9.6pt}\selectfont
   Durham, NC 27708-0320}
\newlength\phonelength
\settowidth\phonelength{%
  \usefont{OT1}{cmr}{m}{n}\fontsize{8pt}{9.6pt}\selectfont
  (919) 660-2829}
\newlength\letterheadheight
\newlength\addressheight
\settoheight\letterheadheight{%
  \usefont{OT1}{cmr}{m}{n}\fontsize{18pt}{21.6pt}\selectfont 
  Duke}
\settoheight\addressheight{
  \usefont{OT1}{cmr}{m}{n}\fontsize{8pt}{9.6pt}\selectfont
  hello}
\addtolength\letterheadheight{2\addressheight}
\addtolength\letterheadheight{2\baselineskip}
\newlength\letterheadwidth
\setlength\letterheadwidth{\paperwidth}
\addtolength\letterheadwidth{-2in}
\newlength\@tmplen
\newlength\headnoshield
\setlength\headnoshield{\letterheadwidth}
\addtolength\headnoshield{-77pt}

\renewcommand{\ps@firstpage}{%
	\renewcommand{\@oddhead}{%
		\if@MakeLetterhead
			\setlength\@tmplen{\textwidth}
			\setlength\textwidth{\letterheadwidth}
			\setlength\headheight{\letterheadheight}
			\hspace*{-\oddsidemargin}
			\@putlogo{\letterheadheight}
			\raisebox{2\addressheight}{\parbox[b]{\headnoshield}{%
			    
				{\usefont{OT1}{cmr}{m}{n}\fontsize{18pt}{21.6pt}\selectfont
					Duke University} 
				\hfill
				{\usefont{OT1}{cmr}{m}{n}\fontsize{14pt}{16.8pt}\selectfont
				 Department of \@department} 
			   \par 
			   \hrulefill 
			   \par
				\parbox[t]{\addresslength}{ \raggedright {%
					\usefont{OT1}{cmr}{m}{n}\fontsize{8pt}{9.6pt}\selectfont
					\fromaddress}}
				\hfill 
				\parbox[t]{\phonelength}{ \raggedright {%
					\usefont{OT1}{cmr}{m}{n}\fontsize{8pt}{9.6pt}\selectfont
				   \telephonenum \par \faxnum\space (fax)}}
				\hfill
				\mbox{ { 
					\usefont{OT1}{cmr}{m}{n}\fontsize{8pt}{9.6pt}\selectfont
					\fromemail}}
			}}
			\setlength\textwidth{\@tmplen}
		\else
			\vspace*{\letterheadheight}
		\fi
	}
	\renewcommand{\@evenhead}{\@oddhead}
	\renewcommand{\@oddfoot}{\@empty}
	\renewcommand{\@evenfoot}{\@empty}
}


\newcommand\@putlogo[1]{%
	\ifpdf
		\IfFileExists{dukeshield.pdf}{%
			\includegraphics[height=#1, keepaspectratio=true]{dukeshield} 
		}{
		  \ClassWarningNoLine{dukedissertation}{%
		  Couldn't find 'dukeshield.pdf', \MessageBreak 
			using LaTeX-picture environment logo}
			\resizebox{!}{#1}{\@LPLogo}
		}
	\else
		\IfFileExists{dukeshield.eps}{%
			\includegraphics[height=#1, keepaspectratio=true]{dukeshield} 
		}{
		  \ClassWarningNoLine{dukedissertation}{%
		  Couldn't find 'dukeshield.eps', \MessageBreak 
		  using LaTeX-picture environment logo}
		\resizebox{!}{#1}{\@LPLogo}
		}
	\fi
}
\newcommand\@LPLogo{%
% $Id: duke-emblem.tex,v 1.2 1992/08/03 15:30:02 mtn Exp $  (Duke)
\setlength{\unitlength}{0.3pt}
{\begin{picture}(96,120)
\put(45,119){\line(-1,0){14}}
\put(63,119){\line(-1,0){14}}
\put(45,118){\line(-1,0){14}}
\put(63,118){\line(-1,0){14}}
\put(29,117){\line(-1,0){10}}
\put(33,117){\line(-1,0){2}}
\put(45,117){\line(-1,0){2}}
\put(51,117){\line(-1,0){2}}
\put(63,117){\line(-1,0){2}}
\put(75,117){\line(-1,0){10}}
\put(29,116){\line(-1,0){10}}
\put(33,116){\line(-1,0){2}}
\put(45,116){\line(-1,0){2}}
\put(51,116){\line(-1,0){2}}
\put(63,116){\line(-1,0){2}}
\put(75,116){\line(-1,0){10}}
\put(17,115){\line(-1,0){18}}
\put(21,115){\line(-1,0){2}}
\put(29,115){\line(-1,0){2}}
\put(33,115){\line(-1,0){2}}
\put(51,115){\line(-1,0){8}}
\put(63,115){\line(-1,0){2}}
\put(67,115){\line(-1,0){2}}
\put(75,115){\line(-1,0){2}}
\put(95,115){\line(-1,0){18}}
\put(17,114){\line(-1,0){18}}
\put(21,114){\line(-1,0){2}}
\put(29,114){\line(-1,0){2}}
\put(33,114){\line(-1,0){2}}
\put(51,114){\line(-1,0){8}}
\put(63,114){\line(-1,0){2}}
\put(67,114){\line(-1,0){2}}
\put(75,114){\line(-1,0){2}}
\put(95,114){\line(-1,0){18}}
\put(1,113){\line(-1,0){2}}
\put(17,113){\line(-1,0){2}}
\put(21,113){\line(-1,0){2}}
\put(33,113){\line(-1,0){6}}
\put(67,113){\line(-1,0){6}}
\put(75,113){\line(-1,0){2}}
\put(79,113){\line(-1,0){2}}
\put(95,113){\line(-1,0){2}}
\put(1,112){\line(-1,0){2}}
\put(17,112){\line(-1,0){2}}
\put(21,112){\line(-1,0){2}}
\put(33,112){\line(-1,0){6}}
\put(67,112){\line(-1,0){6}}
\put(75,112){\line(-1,0){2}}
\put(79,112){\line(-1,0){2}}
\put(95,112){\line(-1,0){2}}
\put(1,111){\line(-1,0){2}}
\put(21,111){\line(-1,0){6}}
\put(79,111){\line(-1,0){6}}
\put(95,111){\line(-1,0){2}}
\put(1,110){\line(-1,0){2}}
\put(21,110){\line(-1,0){6}}
\put(79,110){\line(-1,0){6}}
\put(95,110){\line(-1,0){2}}
\put(1,109){\line(-1,0){2}}
\put(95,109){\line(-1,0){2}}
\put(1,108){\line(-1,0){2}}
\put(95,108){\line(-1,0){2}}
\put(1,107){\line(-1,0){2}}
\put(95,107){\line(-1,0){2}}
\put(1,106){\line(-1,0){2}}
\put(95,106){\line(-1,0){2}}
\put(1,105){\line(-1,0){2}}
\put(95,105){\line(-1,0){2}}
\put(1,104){\line(-1,0){2}}
\put(95,104){\line(-1,0){2}}
\put(1,103){\line(-1,0){2}}
\put(41,103){\line(-1,0){32}}
\put(85,103){\line(-1,0){32}}
\put(95,103){\line(-1,0){2}}
\put(2,102){\line(-1,0){3}}
\put(41,102){\line(-1,0){32}}
\put(85,102){\line(-1,0){32}}
\put(95,102){\line(-1,0){3}}
\put(3,101){\line(-1,0){3}}
\put(11,101){\line(-1,0){2}}
\put(41,101){\line(-1,0){2}}
\put(55,101){\line(-1,0){2}}
\put(85,101){\line(-1,0){2}}
\put(94,101){\line(-1,0){3}}
\put(4,100){\line(-1,0){3}}
\put(11,100){\line(-1,0){2}}
\put(41,100){\line(-1,0){2}}
\put(55,100){\line(-1,0){2}}
\put(85,100){\line(-1,0){2}}
\put(93,100){\line(-1,0){3}}
\put(5,99){\line(-1,0){3}}
\put(11,99){\line(-1,0){2}}
\put(20,99){\line(-1,0){3}}
\put(29,99){\line(-1,0){7}}
\put(41,99){\line(-1,0){2}}
\put(55,99){\line(-1,0){2}}
\put(67,99){\line(-1,0){4}}
\put(75,99){\line(-1,0){4}}
\put(85,99){\line(-1,0){2}}
\put(92,99){\line(-1,0){3}}
\put(6,98){\line(-1,0){3}}
\put(11,98){\line(-1,0){2}}
\put(21,98){\line(-1,0){3}}
\put(30,98){\line(-1,0){7}}
\put(41,98){\line(-1,0){2}}
\put(55,98){\line(-1,0){2}}
\put(68,98){\line(-1,0){5}}
\put(76,98){\line(-1,0){5}}
\put(85,98){\line(-1,0){2}}
\put(91,98){\line(-1,0){3}}
\put(7,97){\line(-1,0){3}}
\put(11,97){\line(-1,0){2}}
\put(22,97){\line(-1,0){3}}
\put(26,97){\line(-1,0){3}}
\put(31,97){\line(-1,0){4}}
\put(41,97){\line(-1,0){2}}
\put(55,97){\line(-1,0){2}}
\put(69,97){\line(-1,0){3}}
\put(77,97){\line(-1,0){5}}
\put(85,97){\line(-1,0){2}}
\put(90,97){\line(-1,0){3}}
\put(7,96){\line(-1,0){2}}
\put(11,96){\line(-1,0){2}}
\put(25,96){\line(-1,0){2}}
\put(32,96){\line(-1,0){4}}
\put(41,96){\line(-1,0){2}}
\put(55,96){\line(-1,0){2}}
\put(69,96){\line(-1,0){2}}
\put(76,96){\line(-1,0){3}}
\put(85,96){\line(-1,0){2}}
\put(89,96){\line(-1,0){2}}
\put(7,95){\line(-1,0){2}}
\put(11,95){\line(-1,0){2}}
\put(21,95){\line(-1,0){2}}
\put(25,95){\line(-1,0){2}}
\put(33,95){\line(-1,0){4}}
\put(41,95){\line(-1,0){2}}
\put(55,95){\line(-1,0){2}}
\put(65,95){\line(-1,0){2}}
\put(69,95){\line(-1,0){2}}
\put(76,95){\line(-1,0){3}}
\put(85,95){\line(-1,0){2}}
\put(89,95){\line(-1,0){2}}
\put(7,94){\line(-1,0){2}}
\put(11,94){\line(-1,0){2}}
\put(21,94){\line(-1,0){2}}
\put(25,94){\line(-1,0){2}}
\put(33,94){\line(-1,0){3}}
\put(41,94){\line(-1,0){2}}
\put(55,94){\line(-1,0){2}}
\put(65,94){\line(-1,0){2}}
\put(69,94){\line(-1,0){2}}
\put(76,94){\line(-1,0){3}}
\put(85,94){\line(-1,0){2}}
\put(89,94){\line(-1,0){2}}
\put(7,93){\line(-1,0){2}}
\put(11,93){\line(-1,0){2}}
\put(21,93){\line(-1,0){2}}
\put(25,93){\line(-1,0){2}}
\put(33,93){\line(-1,0){3}}
\put(41,93){\line(-1,0){2}}
\put(55,93){\line(-1,0){2}}
\put(65,93){\line(-1,0){2}}
\put(69,93){\line(-1,0){2}}
\put(76,93){\line(-1,0){3}}
\put(85,93){\line(-1,0){2}}
\put(89,93){\line(-1,0){2}}
\put(7,92){\line(-1,0){2}}
\put(11,92){\line(-1,0){2}}
\put(21,92){\line(-1,0){2}}
\put(25,92){\line(-1,0){2}}
\put(33,92){\line(-1,0){3}}
\put(41,92){\line(-1,0){2}}
\put(55,92){\line(-1,0){2}}
\put(65,92){\line(-1,0){2}}
\put(69,92){\line(-1,0){2}}
\put(76,92){\line(-1,0){3}}
\put(85,92){\line(-1,0){2}}
\put(89,92){\line(-1,0){2}}
\put(7,91){\line(-1,0){2}}
\put(11,91){\line(-1,0){2}}
\put(21,91){\line(-1,0){4}}
\put(25,91){\line(-1,0){2}}
\put(33,91){\line(-1,0){3}}
\put(41,91){\line(-1,0){2}}
\put(55,91){\line(-1,0){2}}
\put(65,91){\line(-1,0){4}}
\put(69,91){\line(-1,0){2}}
\put(76,91){\line(-1,0){3}}
\put(85,91){\line(-1,0){2}}
\put(89,91){\line(-1,0){2}}
\put(7,90){\line(-1,0){2}}
\put(11,90){\line(-1,0){2}}
\put(21,90){\line(-1,0){4}}
\put(25,90){\line(-1,0){2}}
\put(33,90){\line(-1,0){3}}
\put(41,90){\line(-1,0){2}}
\put(55,90){\line(-1,0){2}}
\put(65,90){\line(-1,0){4}}
\put(69,90){\line(-1,0){2}}
\put(76,90){\line(-1,0){3}}
\put(85,90){\line(-1,0){2}}
\put(89,90){\line(-1,0){2}}
\put(7,89){\line(-1,0){2}}
\put(11,89){\line(-1,0){2}}
\put(21,89){\line(-1,0){2}}
\put(25,89){\line(-1,0){2}}
\put(33,89){\line(-1,0){3}}
\put(41,89){\line(-1,0){2}}
\put(55,89){\line(-1,0){2}}
\put(65,89){\line(-1,0){2}}
\put(69,89){\line(-1,0){2}}
\put(76,89){\line(-1,0){3}}
\put(85,89){\line(-1,0){2}}
\put(89,89){\line(-1,0){2}}
\put(7,88){\line(-1,0){2}}
\put(11,88){\line(-1,0){2}}
\put(21,88){\line(-1,0){2}}
\put(25,88){\line(-1,0){2}}
\put(33,88){\line(-1,0){4}}
\put(41,88){\line(-1,0){2}}
\put(55,88){\line(-1,0){2}}
\put(65,88){\line(-1,0){2}}
\put(69,88){\line(-1,0){2}}
\put(76,88){\line(-1,0){3}}
\put(85,88){\line(-1,0){2}}
\put(89,88){\line(-1,0){2}}
\put(7,87){\line(-1,0){2}}
\put(11,87){\line(-1,0){2}}
\put(21,87){\line(-1,0){2}}
\put(32,87){\line(-1,0){4}}
\put(41,87){\line(-1,0){2}}
\put(55,87){\line(-1,0){2}}
\put(65,87){\line(-1,0){2}}
\put(69,87){\line(-1,0){2}}
\put(76,87){\line(-1,0){4}}
\put(85,87){\line(-1,0){2}}
\put(89,87){\line(-1,0){2}}
\put(7,86){\line(-1,0){2}}
\put(11,86){\line(-1,0){2}}
\put(22,86){\line(-1,0){4}}
\put(31,86){\line(-1,0){4}}
\put(41,86){\line(-1,0){2}}
\put(55,86){\line(-1,0){2}}
\put(66,86){\line(-1,0){3}}
\put(69,86){\line(-1,0){2}}
\put(77,86){\line(-1,0){7}}
\put(85,86){\line(-1,0){2}}
\put(89,86){\line(-1,0){2}}
\put(7,85){\line(-1,0){2}}
\put(11,85){\line(-1,0){2}}
\put(30,85){\line(-1,0){13}}
\put(41,85){\line(-1,0){2}}
\put(51,85){\line(-1,0){8}}
\put(55,85){\line(-1,0){2}}
\put(72,85){\line(-1,0){8}}
\put(79,85){\line(-1,0){5}}
\put(85,85){\line(-1,0){2}}
\put(89,85){\line(-1,0){2}}
\put(7,84){\line(-1,0){2}}
\put(11,84){\line(-1,0){2}}
\put(19,84){\line(-1,0){2}}
\put(29,84){\line(-1,0){7}}
\put(41,84){\line(-1,0){2}}
\put(51,84){\line(-1,0){8}}
\put(55,84){\line(-1,0){2}}
\put(71,84){\line(-1,0){6}}
\put(79,84){\line(-1,0){4}}
\put(85,84){\line(-1,0){2}}
\put(89,84){\line(-1,0){2}}
\put(7,83){\line(-1,0){2}}
\put(11,83){\line(-1,0){2}}
\put(41,83){\line(-1,0){2}}
\put(45,83){\line(-1,0){2}}
\put(51,83){\line(-1,0){2}}
\put(55,83){\line(-1,0){2}}
\put(85,83){\line(-1,0){2}}
\put(89,83){\line(-1,0){2}}
\put(7,82){\line(-1,0){2}}
\put(11,82){\line(-1,0){2}}
\put(41,82){\line(-1,0){2}}
\put(45,82){\line(-1,0){2}}
\put(51,82){\line(-1,0){2}}
\put(55,82){\line(-1,0){2}}
\put(85,82){\line(-1,0){2}}
\put(89,82){\line(-1,0){2}}
\put(7,81){\line(-1,0){2}}
\put(41,81){\line(-1,0){32}}
\put(45,81){\line(-1,0){2}}
\put(51,81){\line(-1,0){2}}
\put(85,81){\line(-1,0){32}}
\put(89,81){\line(-1,0){2}}
\put(7,80){\line(-1,0){2}}
\put(41,80){\line(-1,0){32}}
\put(45,80){\line(-1,0){2}}
\put(51,80){\line(-1,0){2}}
\put(85,80){\line(-1,0){32}}
\put(89,80){\line(-1,0){2}}
\put(7,79){\line(-1,0){2}}
\put(45,79){\line(-1,0){2}}
\put(51,79){\line(-1,0){2}}
\put(89,79){\line(-1,0){2}}
\put(7,78){\line(-1,0){2}}
\put(45,78){\line(-1,0){2}}
\put(51,78){\line(-1,0){2}}
\put(89,78){\line(-1,0){2}}
\put(7,77){\line(-1,0){2}}
\put(45,77){\line(-1,0){12}}
\put(61,77){\line(-1,0){12}}
\put(89,77){\line(-1,0){2}}
\put(7,76){\line(-1,0){2}}
\put(45,76){\line(-1,0){12}}
\put(61,76){\line(-1,0){12}}
\put(89,76){\line(-1,0){2}}
\put(7,75){\line(-1,0){2}}
\put(35,75){\line(-1,0){2}}
\put(61,75){\line(-1,0){2}}
\put(89,75){\line(-1,0){2}}
\put(7,74){\line(-1,0){2}}
\put(35,74){\line(-1,0){2}}
\put(61,74){\line(-1,0){2}}
\put(89,74){\line(-1,0){2}}
\put(7,73){\line(-1,0){2}}
\put(45,73){\line(-1,0){12}}
\put(61,73){\line(-1,0){12}}
\put(89,73){\line(-1,0){2}}
\put(7,72){\line(-1,0){2}}
\put(45,72){\line(-1,0){12}}
\put(61,72){\line(-1,0){12}}
\put(89,72){\line(-1,0){2}}
\put(7,71){\line(-1,0){2}}
\put(45,71){\line(-1,0){2}}
\put(51,71){\line(-1,0){2}}
\put(89,71){\line(-1,0){2}}
\put(7,70){\line(-1,0){2}}
\put(45,70){\line(-1,0){2}}
\put(51,70){\line(-1,0){2}}
\put(89,70){\line(-1,0){2}}
\put(7,69){\line(-1,0){2}}
\put(41,69){\line(-1,0){32}}
\put(45,69){\line(-1,0){2}}
\put(51,69){\line(-1,0){2}}
\put(85,69){\line(-1,0){32}}
\put(89,69){\line(-1,0){2}}
\put(7,68){\line(-1,0){2}}
\put(41,68){\line(-1,0){32}}
\put(45,68){\line(-1,0){2}}
\put(51,68){\line(-1,0){2}}
\put(85,68){\line(-1,0){32}}
\put(89,68){\line(-1,0){2}}
\put(7,67){\line(-1,0){2}}
\put(12,67){\line(-1,0){3}}
\put(41,67){\line(-1,0){2}}
\put(45,67){\line(-1,0){2}}
\put(51,67){\line(-1,0){2}}
\put(55,67){\line(-1,0){2}}
\put(85,67){\line(-1,0){3}}
\put(89,67){\line(-1,0){2}}
\put(7,66){\line(-1,0){2}}
\put(12,66){\line(-1,0){3}}
\put(41,66){\line(-1,0){2}}
\put(45,66){\line(-1,0){2}}
\put(51,66){\line(-1,0){2}}
\put(55,66){\line(-1,0){2}}
\put(85,66){\line(-1,0){3}}
\put(89,66){\line(-1,0){2}}
\put(7,65){\line(-1,0){2}}
\put(13,65){\line(-1,0){4}}
\put(41,65){\line(-1,0){2}}
\put(45,65){\line(-1,0){2}}
\put(51,65){\line(-1,0){2}}
\put(55,65){\line(-1,0){2}}
\put(85,65){\line(-1,0){4}}
\put(89,65){\line(-1,0){2}}
\put(7,64){\line(-1,0){2}}
\put(11,64){\line(-1,0){2}}
\put(14,64){\line(-1,0){2}}
\put(41,64){\line(-1,0){2}}
\put(45,64){\line(-1,0){2}}
\put(51,64){\line(-1,0){2}}
\put(55,64){\line(-1,0){2}}
\put(82,64){\line(-1,0){2}}
\put(85,64){\line(-1,0){2}}
\put(89,64){\line(-1,0){2}}
\put(7,63){\line(-1,0){2}}
\put(11,63){\line(-1,0){2}}
\put(14,63){\line(-1,0){2}}
\put(41,63){\line(-1,0){2}}
\put(45,63){\line(-1,0){2}}
\put(51,63){\line(-1,0){2}}
\put(55,63){\line(-1,0){2}}
\put(82,63){\line(-1,0){2}}
\put(85,63){\line(-1,0){2}}
\put(89,63){\line(-1,0){2}}
\put(7,62){\line(-1,0){2}}
\put(11,62){\line(-1,0){2}}
\put(15,62){\line(-1,0){2}}
\put(41,62){\line(-1,0){2}}
\put(45,62){\line(-1,0){2}}
\put(51,62){\line(-1,0){2}}
\put(55,62){\line(-1,0){2}}
\put(81,62){\line(-1,0){2}}
\put(85,62){\line(-1,0){2}}
\put(89,62){\line(-1,0){2}}
\put(7,61){\line(-1,0){2}}
\put(11,61){\line(-1,0){2}}
\put(15,61){\line(-1,0){2}}
\put(41,61){\line(-1,0){2}}
\put(45,61){\line(-1,0){2}}
\put(51,61){\line(-1,0){2}}
\put(55,61){\line(-1,0){2}}
\put(81,61){\line(-1,0){2}}
\put(85,61){\line(-1,0){2}}
\put(89,61){\line(-1,0){2}}
\put(7,60){\line(-1,0){2}}
\put(11,60){\line(-1,0){2}}
\put(16,60){\line(-1,0){2}}
\put(41,60){\line(-1,0){2}}
\put(45,60){\line(-1,0){2}}
\put(51,60){\line(-1,0){2}}
\put(55,60){\line(-1,0){2}}
\put(80,60){\line(-1,0){2}}
\put(85,60){\line(-1,0){2}}
\put(89,60){\line(-1,0){2}}
\put(7,59){\line(-1,0){2}}
\put(11,59){\line(-1,0){2}}
\put(16,59){\line(-1,0){2}}
\put(29,59){\line(-1,0){8}}
\put(41,59){\line(-1,0){2}}
\put(45,59){\line(-1,0){2}}
\put(51,59){\line(-1,0){2}}
\put(55,59){\line(-1,0){2}}
\put(73,59){\line(-1,0){8}}
\put(80,59){\line(-1,0){2}}
\put(85,59){\line(-1,0){2}}
\put(89,59){\line(-1,0){2}}
\put(7,58){\line(-1,0){2}}
\put(11,58){\line(-1,0){2}}
\put(17,58){\line(-1,0){2}}
\put(29,58){\line(-1,0){8}}
\put(41,58){\line(-1,0){2}}
\put(45,58){\line(-1,0){2}}
\put(51,58){\line(-1,0){2}}
\put(55,58){\line(-1,0){2}}
\put(73,58){\line(-1,0){8}}
\put(79,58){\line(-1,0){2}}
\put(85,58){\line(-1,0){2}}
\put(89,58){\line(-1,0){2}}
\put(7,57){\line(-1,0){2}}
\put(11,57){\line(-1,0){2}}
\put(17,57){\line(-1,0){2}}
\put(23,57){\line(-1,0){2}}
\put(29,57){\line(-1,0){2}}
\put(41,57){\line(-1,0){2}}
\put(45,57){\line(-1,0){2}}
\put(51,57){\line(-1,0){2}}
\put(55,57){\line(-1,0){2}}
\put(67,57){\line(-1,0){2}}
\put(73,57){\line(-1,0){2}}
\put(79,57){\line(-1,0){2}}
\put(85,57){\line(-1,0){2}}
\put(89,57){\line(-1,0){2}}
\put(7,56){\line(-1,0){2}}
\put(11,56){\line(-1,0){2}}
\put(18,56){\line(-1,0){2}}
\put(23,56){\line(-1,0){2}}
\put(29,56){\line(-1,0){2}}
\put(41,56){\line(-1,0){2}}
\put(45,56){\line(-1,0){2}}
\put(51,56){\line(-1,0){2}}
\put(55,56){\line(-1,0){2}}
\put(67,56){\line(-1,0){2}}
\put(73,56){\line(-1,0){2}}
\put(78,56){\line(-1,0){2}}
\put(85,56){\line(-1,0){2}}
\put(89,56){\line(-1,0){2}}
\put(7,55){\line(-1,0){2}}
\put(11,55){\line(-1,0){2}}
\put(18,55){\line(-1,0){2}}
\put(23,55){\line(-1,0){2}}
\put(29,55){\line(-1,0){2}}
\put(41,55){\line(-1,0){2}}
\put(45,55){\line(-1,0){2}}
\put(51,55){\line(-1,0){2}}
\put(55,55){\line(-1,0){2}}
\put(67,55){\line(-1,0){2}}
\put(73,55){\line(-1,0){2}}
\put(78,55){\line(-1,0){2}}
\put(85,55){\line(-1,0){2}}
\put(89,55){\line(-1,0){2}}
\put(7,54){\line(-1,0){2}}
\put(11,54){\line(-1,0){2}}
\put(19,54){\line(-1,0){2}}
\put(23,54){\line(-1,0){2}}
\put(29,54){\line(-1,0){2}}
\put(41,54){\line(-1,0){2}}
\put(45,54){\line(-1,0){2}}
\put(51,54){\line(-1,0){2}}
\put(55,54){\line(-1,0){2}}
\put(67,54){\line(-1,0){2}}
\put(73,54){\line(-1,0){2}}
\put(77,54){\line(-1,0){2}}
\put(85,54){\line(-1,0){2}}
\put(89,54){\line(-1,0){2}}
\put(7,53){\line(-1,0){2}}
\put(11,53){\line(-1,0){2}}
\put(19,53){\line(-1,0){2}}
\put(23,53){\line(-1,0){2}}
\put(29,53){\line(-1,0){2}}
\put(41,53){\line(-1,0){2}}
\put(51,53){\line(-1,0){8}}
\put(55,53){\line(-1,0){2}}
\put(67,53){\line(-1,0){2}}
\put(73,53){\line(-1,0){2}}
\put(77,53){\line(-1,0){2}}
\put(85,53){\line(-1,0){2}}
\put(89,53){\line(-1,0){2}}
\put(7,52){\line(-1,0){2}}
\put(11,52){\line(-1,0){2}}
\put(20,52){\line(-1,0){2}}
\put(23,52){\line(-1,0){2}}
\put(29,52){\line(-1,0){2}}
\put(41,52){\line(-1,0){2}}
\put(51,52){\line(-1,0){8}}
\put(55,52){\line(-1,0){2}}
\put(67,52){\line(-1,0){2}}
\put(73,52){\line(-1,0){2}}
\put(76,52){\line(-1,0){2}}
\put(85,52){\line(-1,0){2}}
\put(89,52){\line(-1,0){2}}
\put(7,51){\line(-1,0){2}}
\put(11,51){\line(-1,0){2}}
\put(20,51){\line(-1,0){2}}
\put(23,51){\line(-1,0){2}}
\put(29,51){\line(-1,0){2}}
\put(41,51){\line(-1,0){2}}
\put(55,51){\line(-1,0){2}}
\put(67,51){\line(-1,0){2}}
\put(73,51){\line(-1,0){2}}
\put(76,51){\line(-1,0){2}}
\put(85,51){\line(-1,0){2}}
\put(89,51){\line(-1,0){2}}
\put(7,50){\line(-1,0){2}}
\put(11,50){\line(-1,0){2}}
\put(23,50){\line(-1,0){4}}
\put(29,50){\line(-1,0){2}}
\put(41,50){\line(-1,0){2}}
\put(55,50){\line(-1,0){2}}
\put(67,50){\line(-1,0){2}}
\put(75,50){\line(-1,0){4}}
\put(85,50){\line(-1,0){2}}
\put(89,50){\line(-1,0){2}}
\put(7,49){\line(-1,0){2}}
\put(11,49){\line(-1,0){2}}
\put(23,49){\line(-1,0){4}}
\put(29,49){\line(-1,0){2}}
\put(41,49){\line(-1,0){2}}
\put(55,49){\line(-1,0){2}}
\put(67,49){\line(-1,0){2}}
\put(75,49){\line(-1,0){4}}
\put(85,49){\line(-1,0){2}}
\put(89,49){\line(-1,0){2}}
\put(7,48){\line(-1,0){2}}
\put(11,48){\line(-1,0){2}}
\put(23,48){\line(-1,0){3}}
\put(29,48){\line(-1,0){2}}
\put(41,48){\line(-1,0){2}}
\put(55,48){\line(-1,0){2}}
\put(67,48){\line(-1,0){2}}
\put(74,48){\line(-1,0){3}}
\put(85,48){\line(-1,0){2}}
\put(89,48){\line(-1,0){2}}
\put(7,47){\line(-1,0){2}}
\put(11,47){\line(-1,0){2}}
\put(23,47){\line(-1,0){3}}
\put(29,47){\line(-1,0){2}}
\put(41,47){\line(-1,0){2}}
\put(51,47){\line(-1,0){8}}
\put(55,47){\line(-1,0){2}}
\put(67,47){\line(-1,0){2}}
\put(74,47){\line(-1,0){3}}
\put(85,47){\line(-1,0){2}}
\put(89,47){\line(-1,0){2}}
\put(7,46){\line(-1,0){2}}
\put(11,46){\line(-1,0){2}}
\put(23,46){\line(-1,0){2}}
\put(29,46){\line(-1,0){2}}
\put(41,46){\line(-1,0){2}}
\put(51,46){\line(-1,0){8}}
\put(55,46){\line(-1,0){2}}
\put(67,46){\line(-1,0){2}}
\put(73,46){\line(-1,0){2}}
\put(85,46){\line(-1,0){2}}
\put(89,46){\line(-1,0){2}}
\put(7,45){\line(-1,0){2}}
\put(11,45){\line(-1,0){2}}
\put(23,45){\line(-1,0){2}}
\put(29,45){\line(-1,0){2}}
\put(41,45){\line(-1,0){2}}
\put(45,45){\line(-1,0){2}}
\put(51,45){\line(-1,0){2}}
\put(55,45){\line(-1,0){2}}
\put(67,45){\line(-1,0){2}}
\put(73,45){\line(-1,0){2}}
\put(85,45){\line(-1,0){2}}
\put(89,45){\line(-1,0){2}}
\put(7,44){\line(-1,0){2}}
\put(11,44){\line(-1,0){2}}
\put(23,44){\line(-1,0){2}}
\put(29,44){\line(-1,0){2}}
\put(41,44){\line(-1,0){2}}
\put(45,44){\line(-1,0){2}}
\put(51,44){\line(-1,0){2}}
\put(55,44){\line(-1,0){2}}
\put(67,44){\line(-1,0){2}}
\put(73,44){\line(-1,0){2}}
\put(85,44){\line(-1,0){2}}
\put(89,44){\line(-1,0){2}}
\put(7,43){\line(-1,0){2}}
\put(11,43){\line(-1,0){2}}
\put(23,43){\line(-1,0){2}}
\put(29,43){\line(-1,0){2}}
\put(41,43){\line(-1,0){2}}
\put(45,43){\line(-1,0){2}}
\put(51,43){\line(-1,0){2}}
\put(55,43){\line(-1,0){2}}
\put(67,43){\line(-1,0){2}}
\put(73,43){\line(-1,0){2}}
\put(85,43){\line(-1,0){2}}
\put(89,43){\line(-1,0){2}}
\put(7,42){\line(-1,0){2}}
\put(11,42){\line(-1,0){2}}
\put(23,42){\line(-1,0){2}}
\put(29,42){\line(-1,0){2}}
\put(41,42){\line(-1,0){2}}
\put(45,42){\line(-1,0){2}}
\put(51,42){\line(-1,0){2}}
\put(55,42){\line(-1,0){2}}
\put(67,42){\line(-1,0){2}}
\put(73,42){\line(-1,0){2}}
\put(85,42){\line(-1,0){2}}
\put(89,42){\line(-1,0){2}}
\put(7,41){\line(-1,0){2}}
\put(11,41){\line(-1,0){2}}
\put(23,41){\line(-1,0){2}}
\put(29,41){\line(-1,0){2}}
\put(41,41){\line(-1,0){2}}
\put(45,41){\line(-1,0){2}}
\put(51,41){\line(-1,0){2}}
\put(55,41){\line(-1,0){2}}
\put(67,41){\line(-1,0){2}}
\put(73,41){\line(-1,0){2}}
\put(85,41){\line(-1,0){2}}
\put(89,41){\line(-1,0){2}}
\put(7,40){\line(-1,0){2}}
\put(11,40){\line(-1,0){2}}
\put(23,40){\line(-1,0){2}}
\put(29,40){\line(-1,0){2}}
\put(41,40){\line(-1,0){2}}
\put(45,40){\line(-1,0){2}}
\put(51,40){\line(-1,0){2}}
\put(55,40){\line(-1,0){2}}
\put(67,40){\line(-1,0){2}}
\put(73,40){\line(-1,0){2}}
\put(85,40){\line(-1,0){2}}
\put(89,40){\line(-1,0){2}}
\put(7,39){\line(-1,0){2}}
\put(11,39){\line(-1,0){2}}
\put(23,39){\line(-1,0){2}}
\put(29,39){\line(-1,0){2}}
\put(41,39){\line(-1,0){2}}
\put(45,39){\line(-1,0){2}}
\put(51,39){\line(-1,0){2}}
\put(55,39){\line(-1,0){2}}
\put(67,39){\line(-1,0){2}}
\put(73,39){\line(-1,0){2}}
\put(85,39){\line(-1,0){2}}
\put(89,39){\line(-1,0){2}}
\put(7,38){\line(-1,0){2}}
\put(11,38){\line(-1,0){2}}
\put(23,38){\line(-1,0){2}}
\put(29,38){\line(-1,0){2}}
\put(41,38){\line(-1,0){2}}
\put(45,38){\line(-1,0){2}}
\put(51,38){\line(-1,0){2}}
\put(55,38){\line(-1,0){2}}
\put(67,38){\line(-1,0){2}}
\put(73,38){\line(-1,0){2}}
\put(85,38){\line(-1,0){2}}
\put(89,38){\line(-1,0){2}}
\put(7,37){\line(-1,0){2}}
\put(11,37){\line(-1,0){2}}
\put(23,37){\line(-1,0){2}}
\put(29,37){\line(-1,0){2}}
\put(41,37){\line(-1,0){2}}
\put(45,37){\line(-1,0){2}}
\put(51,37){\line(-1,0){2}}
\put(55,37){\line(-1,0){2}}
\put(67,37){\line(-1,0){2}}
\put(73,37){\line(-1,0){2}}
\put(85,37){\line(-1,0){2}}
\put(89,37){\line(-1,0){2}}
\put(7,36){\line(-1,0){2}}
\put(11,36){\line(-1,0){2}}
\put(23,36){\line(-1,0){2}}
\put(29,36){\line(-1,0){2}}
\put(41,36){\line(-1,0){2}}
\put(45,36){\line(-1,0){2}}
\put(51,36){\line(-1,0){2}}
\put(55,36){\line(-1,0){2}}
\put(67,36){\line(-1,0){2}}
\put(73,36){\line(-1,0){2}}
\put(85,36){\line(-1,0){2}}
\put(89,36){\line(-1,0){2}}
\put(7,35){\line(-1,0){2}}
\put(11,35){\line(-1,0){2}}
\put(23,35){\line(-1,0){2}}
\put(29,35){\line(-1,0){2}}
\put(41,35){\line(-1,0){2}}
\put(45,35){\line(-1,0){2}}
\put(51,35){\line(-1,0){2}}
\put(55,35){\line(-1,0){2}}
\put(67,35){\line(-1,0){2}}
\put(73,35){\line(-1,0){2}}
\put(85,35){\line(-1,0){2}}
\put(89,35){\line(-1,0){2}}
\put(7,34){\line(-1,0){2}}
\put(11,34){\line(-1,0){2}}
\put(23,34){\line(-1,0){2}}
\put(29,34){\line(-1,0){2}}
\put(41,34){\line(-1,0){2}}
\put(45,34){\line(-1,0){2}}
\put(51,34){\line(-1,0){2}}
\put(55,34){\line(-1,0){2}}
\put(67,34){\line(-1,0){2}}
\put(73,34){\line(-1,0){2}}
\put(85,34){\line(-1,0){2}}
\put(89,34){\line(-1,0){2}}
\put(7,33){\line(-1,0){2}}
\put(11,33){\line(-1,0){2}}
\put(23,33){\line(-1,0){2}}
\put(29,33){\line(-1,0){2}}
\put(41,33){\line(-1,0){2}}
\put(45,33){\line(-1,0){2}}
\put(51,33){\line(-1,0){2}}
\put(55,33){\line(-1,0){2}}
\put(67,33){\line(-1,0){2}}
\put(73,33){\line(-1,0){2}}
\put(85,33){\line(-1,0){2}}
\put(89,33){\line(-1,0){2}}
\put(7,32){\line(-1,0){2}}
\put(11,32){\line(-1,0){2}}
\put(23,32){\line(-1,0){2}}
\put(30,32){\line(-1,0){3}}
\put(41,32){\line(-1,0){2}}
\put(45,32){\line(-1,0){2}}
\put(51,32){\line(-1,0){2}}
\put(55,32){\line(-1,0){2}}
\put(67,32){\line(-1,0){3}}
\put(73,32){\line(-1,0){2}}
\put(85,32){\line(-1,0){2}}
\put(89,32){\line(-1,0){2}}
\put(7,31){\line(-1,0){2}}
\put(11,31){\line(-1,0){2}}
\put(23,31){\line(-1,0){2}}
\put(30,31){\line(-1,0){3}}
\put(41,31){\line(-1,0){2}}
\put(45,31){\line(-1,0){2}}
\put(51,31){\line(-1,0){2}}
\put(55,31){\line(-1,0){2}}
\put(67,31){\line(-1,0){3}}
\put(73,31){\line(-1,0){2}}
\put(85,31){\line(-1,0){2}}
\put(89,31){\line(-1,0){2}}
\put(7,30){\line(-1,0){2}}
\put(11,30){\line(-1,0){2}}
\put(23,30){\line(-1,0){2}}
\put(31,30){\line(-1,0){4}}
\put(41,30){\line(-1,0){2}}
\put(45,30){\line(-1,0){2}}
\put(51,30){\line(-1,0){2}}
\put(55,30){\line(-1,0){2}}
\put(67,30){\line(-1,0){4}}
\put(73,30){\line(-1,0){2}}
\put(85,30){\line(-1,0){2}}
\put(89,30){\line(-1,0){2}}
\put(7,29){\line(-1,0){2}}
\put(11,29){\line(-1,0){2}}
\put(23,29){\line(-1,0){2}}
\put(31,29){\line(-1,0){4}}
\put(41,29){\line(-1,0){2}}
\put(45,29){\line(-1,0){2}}
\put(51,29){\line(-1,0){2}}
\put(55,29){\line(-1,0){2}}
\put(67,29){\line(-1,0){4}}
\put(73,29){\line(-1,0){2}}
\put(85,29){\line(-1,0){2}}
\put(89,29){\line(-1,0){2}}
\put(7,28){\line(-1,0){2}}
\put(12,28){\line(-1,0){3}}
\put(23,28){\line(-1,0){2}}
\put(32,28){\line(-1,0){5}}
\put(41,28){\line(-1,0){2}}
\put(45,28){\line(-1,0){2}}
\put(51,28){\line(-1,0){2}}
\put(55,28){\line(-1,0){2}}
\put(67,28){\line(-1,0){5}}
\put(73,28){\line(-1,0){2}}
\put(85,28){\line(-1,0){3}}
\put(89,28){\line(-1,0){2}}
\put(7,27){\line(-1,0){2}}
\put(13,27){\line(-1,0){3}}
\put(23,27){\line(-1,0){2}}
\put(29,27){\line(-1,0){2}}
\put(32,27){\line(-1,0){2}}
\put(41,27){\line(-1,0){2}}
\put(45,27){\line(-1,0){2}}
\put(51,27){\line(-1,0){2}}
\put(55,27){\line(-1,0){2}}
\put(64,27){\line(-1,0){2}}
\put(67,27){\line(-1,0){2}}
\put(73,27){\line(-1,0){2}}
\put(84,27){\line(-1,0){3}}
\put(89,27){\line(-1,0){2}}
\put(8,26){\line(-1,0){3}}
\put(14,26){\line(-1,0){3}}
\put(23,26){\line(-1,0){2}}
\put(29,26){\line(-1,0){2}}
\put(33,26){\line(-1,0){2}}
\put(41,26){\line(-1,0){2}}
\put(45,26){\line(-1,0){2}}
\put(51,26){\line(-1,0){2}}
\put(55,26){\line(-1,0){2}}
\put(63,26){\line(-1,0){2}}
\put(67,26){\line(-1,0){2}}
\put(73,26){\line(-1,0){2}}
\put(83,26){\line(-1,0){3}}
\put(89,26){\line(-1,0){3}}
\put(8,25){\line(-1,0){2}}
\put(15,25){\line(-1,0){3}}
\put(29,25){\line(-1,0){8}}
\put(33,25){\line(-1,0){2}}
\put(41,25){\line(-1,0){2}}
\put(45,25){\line(-1,0){2}}
\put(51,25){\line(-1,0){2}}
\put(55,25){\line(-1,0){2}}
\put(63,25){\line(-1,0){2}}
\put(73,25){\line(-1,0){8}}
\put(82,25){\line(-1,0){3}}
\put(88,25){\line(-1,0){2}}
\put(9,24){\line(-1,0){3}}
\put(16,24){\line(-1,0){3}}
\put(29,24){\line(-1,0){8}}
\put(34,24){\line(-1,0){2}}
\put(41,24){\line(-1,0){2}}
\put(45,24){\line(-1,0){2}}
\put(51,24){\line(-1,0){2}}
\put(55,24){\line(-1,0){2}}
\put(62,24){\line(-1,0){2}}
\put(73,24){\line(-1,0){8}}
\put(81,24){\line(-1,0){3}}
\put(88,24){\line(-1,0){3}}
\put(9,23){\line(-1,0){2}}
\put(17,23){\line(-1,0){3}}
\put(34,23){\line(-1,0){2}}
\put(41,23){\line(-1,0){2}}
\put(45,23){\line(-1,0){2}}
\put(51,23){\line(-1,0){2}}
\put(55,23){\line(-1,0){2}}
\put(62,23){\line(-1,0){2}}
\put(80,23){\line(-1,0){3}}
\put(87,23){\line(-1,0){2}}
\put(10,22){\line(-1,0){2}}
\put(18,22){\line(-1,0){3}}
\put(35,22){\line(-1,0){2}}
\put(41,22){\line(-1,0){2}}
\put(45,22){\line(-1,0){2}}
\put(51,22){\line(-1,0){2}}
\put(55,22){\line(-1,0){2}}
\put(61,22){\line(-1,0){2}}
\put(79,22){\line(-1,0){3}}
\put(87,22){\line(-1,0){3}}
\put(11,21){\line(-1,0){3}}
\put(19,21){\line(-1,0){3}}
\put(35,21){\line(-1,0){2}}
\put(41,21){\line(-1,0){2}}
\put(45,21){\line(-1,0){2}}
\put(51,21){\line(-1,0){2}}
\put(55,21){\line(-1,0){2}}
\put(61,21){\line(-1,0){2}}
\put(78,21){\line(-1,0){3}}
\put(86,21){\line(-1,0){3}}
\put(12,20){\line(-1,0){3}}
\put(20,20){\line(-1,0){3}}
\put(36,20){\line(-1,0){2}}
\put(41,20){\line(-1,0){2}}
\put(45,20){\line(-1,0){2}}
\put(51,20){\line(-1,0){2}}
\put(55,20){\line(-1,0){2}}
\put(60,20){\line(-1,0){2}}
\put(77,20){\line(-1,0){3}}
\put(85,20){\line(-1,0){3}}
\put(13,19){\line(-1,0){3}}
\put(21,19){\line(-1,0){3}}
\put(36,19){\line(-1,0){2}}
\put(41,19){\line(-1,0){2}}
\put(45,19){\line(-1,0){2}}
\put(51,19){\line(-1,0){2}}
\put(55,19){\line(-1,0){2}}
\put(60,19){\line(-1,0){2}}
\put(76,19){\line(-1,0){3}}
\put(84,19){\line(-1,0){3}}
\put(14,18){\line(-1,0){3}}
\put(22,18){\line(-1,0){3}}
\put(37,18){\line(-1,0){2}}
\put(41,18){\line(-1,0){2}}
\put(45,18){\line(-1,0){2}}
\put(51,18){\line(-1,0){2}}
\put(55,18){\line(-1,0){2}}
\put(59,18){\line(-1,0){2}}
\put(75,18){\line(-1,0){3}}
\put(83,18){\line(-1,0){3}}
\put(15,17){\line(-1,0){3}}
\put(24,17){\line(-1,0){4}}
\put(37,17){\line(-1,0){2}}
\put(41,17){\line(-1,0){2}}
\put(45,17){\line(-1,0){2}}
\put(51,17){\line(-1,0){2}}
\put(55,17){\line(-1,0){2}}
\put(59,17){\line(-1,0){2}}
\put(74,17){\line(-1,0){4}}
\put(82,17){\line(-1,0){3}}
\put(16,16){\line(-1,0){3}}
\put(25,16){\line(-1,0){3}}
\put(38,16){\line(-1,0){2}}
\put(41,16){\line(-1,0){2}}
\put(45,16){\line(-1,0){2}}
\put(51,16){\line(-1,0){2}}
\put(55,16){\line(-1,0){2}}
\put(58,16){\line(-1,0){2}}
\put(72,16){\line(-1,0){3}}
\put(81,16){\line(-1,0){3}}
\put(17,15){\line(-1,0){3}}
\put(27,15){\line(-1,0){4}}
\put(38,15){\line(-1,0){2}}
\put(41,15){\line(-1,0){2}}
\put(45,15){\line(-1,0){2}}
\put(51,15){\line(-1,0){2}}
\put(55,15){\line(-1,0){2}}
\put(58,15){\line(-1,0){2}}
\put(71,15){\line(-1,0){4}}
\put(80,15){\line(-1,0){3}}
\put(18,14){\line(-1,0){3}}
\put(29,14){\line(-1,0){4}}
\put(41,14){\line(-1,0){4}}
\put(45,14){\line(-1,0){2}}
\put(51,14){\line(-1,0){2}}
\put(57,14){\line(-1,0){4}}
\put(69,14){\line(-1,0){4}}
\put(79,14){\line(-1,0){3}}
\put(19,13){\line(-1,0){3}}
\put(31,13){\line(-1,0){4}}
\put(41,13){\line(-1,0){4}}
\put(51,13){\line(-1,0){8}}
\put(57,13){\line(-1,0){4}}
\put(67,13){\line(-1,0){4}}
\put(78,13){\line(-1,0){4}}
\put(21,12){\line(-1,0){4}}
\put(33,12){\line(-1,0){4}}
\put(41,12){\line(-1,0){3}}
\put(51,12){\line(-1,0){8}}
\put(56,12){\line(-1,0){3}}
\put(65,12){\line(-1,0){4}}
\put(76,12){\line(-1,0){3}}
\put(22,11){\line(-1,0){3}}
\put(35,11){\line(-1,0){4}}
\put(41,11){\line(-1,0){2}}
\put(55,11){\line(-1,0){2}}
\put(63,11){\line(-1,0){4}}
\put(75,11){\line(-1,0){3}}
\put(24,10){\line(-1,0){4}}
\put(37,10){\line(-1,0){4}}
\put(41,10){\line(-1,0){2}}
\put(55,10){\line(-1,0){2}}
\put(61,10){\line(-1,0){4}}
\put(74,10){\line(-1,0){4}}
\put(26,9){\line(-1,0){4}}
\put(41,9){\line(-1,0){6}}
\put(59,9){\line(-1,0){6}}
\put(72,9){\line(-1,0){4}}
\put(28,8){\line(-1,0){5}}
\put(41,8){\line(-1,0){4}}
\put(57,8){\line(-1,0){4}}
\put(71,8){\line(-1,0){5}}
\put(31,7){\line(-1,0){6}}
\put(68,7){\line(-1,0){5}}
\put(34,6){\line(-1,0){7}}
\put(67,6){\line(-1,0){7}}
\put(37,5){\line(-1,0){7}}
\put(64,5){\line(-1,0){7}}
\put(40,4){\line(-1,0){7}}
\put(61,4){\line(-1,0){7}}
\put(43,3){\line(-1,0){6}}
\put(57,3){\line(-1,0){6}}
\put(45,2){\line(-1,0){6}}
\put(55,2){\line(-1,0){6}}
\put(52,1){\line(-1,0){10}}
\put(49,0){\line(-1,0){4}}
\end{picture}}
}


